@@ -47,6 +47,7 @@ class ConfigInput(TypedDict):
 class ConfigReference(TypedDict):
     image: str | Path
     file: str | Path
+    color: str | Path
 
 
 class ConfigOutput(TypedDict):
@@ -95,6 +96,8 @@ def create_processing_config(config_dict: Config) -> Config:
         config_dict["reference"]["file"] = Path(config_dict["reference"]["file"])
     if type(config_dict["reference"]["image"]) == str:
         config_dict["reference"]["image"] = Path(config_dict["reference"]["image"])
+    if type(config_dict["reference"]["color"]) == str:
+        config_dict["reference"]["color"] = Path(config_dict["reference"]["color"])
 
     # Remove duplicates radii of extraction
     radii = list(set(config_dict["processing"]["radii_of_extraction"]))
@@ -179,11 +182,17 @@ def verify_optional_image_options(options: Dict) -> bool:
         return False
     crop_region: List[List[int]] = options.get("crop_region", [])
     # Ensure that all values in crop_region are non-negative integers
-    values: List[int] = reduce(lambda prev, curr: prev + curr, crop_region, [])
-    is_valid = all([type(i) == i and i >= 0 for i in values])
-    if not is_valid:
-        sys.stderr.write.write("Crop region must be an array of array of integers >= 0\n")
-    return is_valid
+    try:
+        for i in crop_region:
+            for j in i:
+                valid_values = all([type(x) == int and x >= 0 for x in j])
+                if not valid_values:
+                    sys.stderr.write(f"Invalid value detected in crop_region {j}.\n")
+                    return False
+    except Exception as e:
+        sys.stderr.write(f"Error in crop_region {j}.\n")
+        return False
+    return True  # Valid
 
 
 def is_night_name_valid(NIGHT_INPUT_PATH: Path):
@@ -308,6 +317,7 @@ def validate_file(file_path: Path, on_success: Callable[[Config], None]) -> None
             "reference": {
                 "image": str(reference_image),
                 "file": str(reference_file),
+                "color": str(color_ref_file),
             },
             "input": {"nights": list(list_of_nights)},
             "output": {"path": str(_)},
